| get_all_config | R Documentation |
Retrieve full configuration code as a list for applying in the plot styling and export settings.
get_all_config(
plot_style = "default",
plot_config = TRUE,
export_config = TRUE
)
plot_style |
Character. Plot style to use (currently only '"default"' is supported). |
plot_config |
Logical. If 'TRUE', prints the plot style configuration. |
export_config |
Logical. If 'TRUE', prints the export configuration. |
Onece printing into the console, users can simply copy and paste the entire list of configurations, rename it (if needed), and use it in your plot functions directly.
A named list containing the current default values for all GTAPViz configuration options, including plot styles, table formats, and export parameters.
Pattawee Puangchit
# Input Path:
input_path <- system.file("extdata/in", package = "GTAPViz")
sl4.plot.data <- readRDS(file.path(input_path, "sl4.plot.data.rds"))
# Retrive configurations
get_all_config()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.